==> wormux_0.7.9.orig.tar.gz: wormux-0.7.9/src/weapon/syringe.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Weapon Syringe
 *****************************************************************************/

#ifndef SYRINGE_H
#define SYRINGE_H
//-----------------------------------------------------------------------------
#include "../include/base.h"
#include "weapon.h"
//-----------------------------------------------------------------------------

class SyringeConfig : public WeaponConfig
{
  public:
    uint range;
    uint damage;
    uint turns;
  public:
    SyringeConfig();
    void LoadXml(xmlpp::Element *elem);
};

//-----------------------------------------------------------------------------

class Syringe : public Weapon
{
  protected:
    bool p_Shoot();
    void Refresh();

    void Draw();

  public:
    Syringe();
    SyringeConfig &cfg();
};

//-----------------------------------------------------------------------------
#endif /* SYRINGE_H */

==> wormux_0.8.orig.tar.gz: wormux-0.8/src/weapon/syringe.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2008 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Weapon Syringe
 *****************************************************************************/

#ifndef SYRINGE_H
#define SYRINGE_H
//-----------------------------------------------------------------------------
#include "include/base.h"
#include "weapon.h"
//-----------------------------------------------------------------------------

class SyringeConfig;

class Syringe : public Weapon
{
  protected:
    bool p_Shoot();
    void Refresh() { if (IsInUse()) m_is_active = false; };

    void Draw() { Weapon::Draw(); };

  public:
    Syringe();
    SyringeConfig &cfg();

    void UpdateTranslationStrings();
    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
};

//-----------------------------------------------------------------------------
#endif /* SYRINGE_H */
